@@ -10,7 +10,9 @@ class TestGRPCClientClass:
     def test_account_data_loading(self):
         account = Account(seed_phrase=self.seed_phrase)
 
-        client = GRPCClient()
+        client = GRPCClient(host="grpc.cosmos.interbloc.org",
+                            port=443,
+                            ssl=True)
 
         client.load_account_data(account)
 
@@ -25,7 +27,9 @@ class TestGRPCClientClass:
             next_sequence=0,
         )
 
-        client = GRPCClient()
+        client = GRPCClient(host="grpc.cosmos.interbloc.org",
+                            port=443,
+                            ssl=True)
 
         fee = Coin(denom="uatom", amount="1000")
 
@@ -46,6 +50,5 @@ class TestGRPCClientClass:
         tx_data = client.broadcast_transaction(transaction=tx)
 
         assert (
-            tx_data[0] ==
-            "54B845AEB1523803D4EAF2330AE5759A83458CB5F0211159D04CC257428503C4"
-        )
+            tx_data["hash"] ==
+            "54B845AEB1523803D4EAF2330AE5759A83458CB5F0211159D04CC257428503C4")
